<?php
include 'connection.php';


if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Check if the image is provided
    if (empty($_POST['image_base64'])) {
        die('Error: Base64 image data is required.');
    }

    // Get the base64 encoded image data
    $imageData = $_POST['image_base64'];

    // Validate if the image is a PNG or JPG
    if (!preg_match('/^data:image\/(png|jpeg);base64,/', $imageData, $imageType)) {
        die('Error: Only PNG or JPG images are allowed.');
    }

    // Extract the image type (png or jpeg)
    $imageType = $imageType[1];

    // Convert base64 data to binary
    $binaryImageData = base64_decode(preg_replace('#^data:image/\w+;base64,#i', '', $imageData));

    // Check if the file is empty after decoding
    if (empty($binaryImageData)) {
        die('Error: Invalid base64 image data.');
    }

    // Generate a unique filename
    $imageName = time() . '.' . $imageType;

    // Define the upload directory
    $uploadDirectory = 'uploads/';

    // Create the uploads directory if it doesn't exist
    if (!is_dir($uploadDirectory)) {
        mkdir($uploadDirectory, 0755, true);
    }

    // Define the file path
    $filePath = $uploadDirectory . $imageName;

    // Save the image to the server
    file_put_contents($filePath, $binaryImageData);

    // Insert image details into the database
    try {
        $stmt = $pdo->prepare("INSERT INTO crop_images (image_path, created_at) VALUES (:filename, NOW())");
        $stmt->bindParam(':filename', $imageName);
        $stmt->execute();
    } catch (PDOException $e) {
        die('Error inserting data into the database: ' . $e->getMessage());
    }

    // Redirect back to index.php with a success message
    header('Location: index.php?success=1'); // Append success=1 as a query parameter
    exit();
} else {
    // If the form is not submitted, redirect to the homepage or display an error message
    header('Location: index.php'); // Change 'index.php' to the actual filename or URL
    exit();
}
